/*  ----------------------------------------------------------------------
    sf Firewall Software -- a TCP/IP packet filter for Linux
    Copyright (C) 1996 Robert Muchsel and Roland Schmid

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    Please address all correspondence concerning the software to 
    firewall-bugs@switch.ch.
    ----------------------------------------------------------------------  */

/* 
 * sf firewall: protocol names
 *
 * $Id: sf_proto.h,v 1.2 1995/07/13 14:37:44 roland Rel $
 */

#ifndef _SF_PROTO_H
#define _SF_PROTO_H

extern char *protocol[];
extern char *icmptype[];

#define MAX_PROTOCOL 103   /* Last non-template entry in protocol array */
#define MAX_ICMPTYPE  40   /* Last entry in icmptype array */

#endif
